Class: Google::Cloud::BackupDR::V1::AlloyDbClusterBackupProperties

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/backupdr/v1/backupvault_alloydb.rb

Overview

AlloyDbClusterBackupProperties represents AlloyDB cluster backup properties. .

Instance Attribute Summary collapse

Instance Attribute Details

#chain_id::String (readonly)

Returns Output only. The chain id of this backup. Backups belonging to the same chain are sharing the same chain id. This property is calculated and maintained by BackupDR.

Returns:

  • (::String)

    Output only. The chain id of this backup. Backups belonging to the same chain are sharing the same chain id. This property is calculated and maintained by BackupDR.



53
54
55
56
# File 'proto_docs/google/cloud/backupdr/v1/backupvault_alloydb.rb', line 53

class AlloyDbClusterBackupProperties
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#database_version::String (readonly)

Returns Output only. The PostgreSQL major version of the AlloyDB cluster when the backup was taken.

Returns:

  • (::String)

    Output only. The PostgreSQL major version of the AlloyDB cluster when the backup was taken.



53
54
55
56
# File 'proto_docs/google/cloud/backupdr/v1/backupvault_alloydb.rb', line 53

class AlloyDbClusterBackupProperties
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#description::String

Returns An optional text description for the backup.

Returns:

  • (::String)

    An optional text description for the backup.



53
54
55
56
# File 'proto_docs/google/cloud/backupdr/v1/backupvault_alloydb.rb', line 53

class AlloyDbClusterBackupProperties
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#stored_bytes::Integer (readonly)

Returns Output only. Storage usage of this particular backup.

Returns:

  • (::Integer)

    Output only. Storage usage of this particular backup



53
54
55
56
# File 'proto_docs/google/cloud/backupdr/v1/backupvault_alloydb.rb', line 53

class AlloyDbClusterBackupProperties
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end