Module: Google::Cloud::BackupDR::V1::BackupConfigDetails::State

Defined in:
proto_docs/google/cloud/backupdr/v1/protection_summary.rb

Overview

The state tells whether the backup config is active or not.

Constant Summary collapse

STATE_UNSPECIFIED =

Backup config state not set.

0
ACTIVE =

The config is in an active state protecting the resource

1
INACTIVE =

The config is currently not protecting the resource. Either because it is disabled or the owning project has been deleted without cleanup of the actual resource.

2
ERROR =

The config still exists but because of some error state it is not protecting the resource. Like the source project is deleted. For eg. PlanAssociation, BackupPlan is deleted.

3