Class: Google::Cloud::BackupDR::V1::BackupConfigInfo
- Inherits:
-
Object
- Object
- Google::Cloud::BackupDR::V1::BackupConfigInfo
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/backupdr/v1/backupvault.rb
Overview
BackupConfigInfo has information about how the resource is configured for Backup and about the most recent backup to this vault.
Defined Under Namespace
Modules: LastBackupState
Instance Attribute Summary collapse
-
#backup_appliance_backup_config ⇒ ::Google::Cloud::BackupDR::V1::BackupApplianceBackupConfig
Configuration for an application backed up by a Backup Appliance.
-
#gcp_backup_config ⇒ ::Google::Cloud::BackupDR::V1::GcpBackupConfig
Configuration for a Google Cloud resource.
-
#last_backup_error ⇒ ::Google::Rpc::Status
readonly
Output only.
-
#last_backup_state ⇒ ::Google::Cloud::BackupDR::V1::BackupConfigInfo::LastBackupState
readonly
Output only.
-
#last_successful_backup_consistency_time ⇒ ::Google::Protobuf::Timestamp
readonly
Output only.
Instance Attribute Details
#backup_appliance_backup_config ⇒ ::Google::Cloud::BackupDR::V1::BackupApplianceBackupConfig
Returns Configuration for an application backed up by a Backup Appliance.
Note: The following fields are mutually exclusive: backup_appliance_backup_config, gcp_backup_config. If a field in that set is populated, all other fields in the set will automatically be cleared.
306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 |
# File 'proto_docs/google/cloud/backupdr/v1/backupvault.rb', line 306 class BackupConfigInfo include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # LastBackupstate tracks whether the last backup was not yet started, # successful, failed, or could not be run because of the lack of permissions. module LastBackupState # Status not set. LAST_BACKUP_STATE_UNSPECIFIED = 0 # The first backup has not yet completed FIRST_BACKUP_PENDING = 1 # The most recent backup was successful SUCCEEDED = 2 # The most recent backup failed FAILED = 3 # The most recent backup could not be run/failed because of the lack of # permissions PERMISSION_DENIED = 4 end end |
#gcp_backup_config ⇒ ::Google::Cloud::BackupDR::V1::GcpBackupConfig
Returns Configuration for a Google Cloud resource.
Note: The following fields are mutually exclusive: gcp_backup_config, backup_appliance_backup_config. If a field in that set is populated, all other fields in the set will automatically be cleared.
306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 |
# File 'proto_docs/google/cloud/backupdr/v1/backupvault.rb', line 306 class BackupConfigInfo include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # LastBackupstate tracks whether the last backup was not yet started, # successful, failed, or could not be run because of the lack of permissions. module LastBackupState # Status not set. LAST_BACKUP_STATE_UNSPECIFIED = 0 # The first backup has not yet completed FIRST_BACKUP_PENDING = 1 # The most recent backup was successful SUCCEEDED = 2 # The most recent backup failed FAILED = 3 # The most recent backup could not be run/failed because of the lack of # permissions PERMISSION_DENIED = 4 end end |
#last_backup_error ⇒ ::Google::Rpc::Status (readonly)
Returns Output only. If the last backup failed, this field has the error message.
306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 |
# File 'proto_docs/google/cloud/backupdr/v1/backupvault.rb', line 306 class BackupConfigInfo include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # LastBackupstate tracks whether the last backup was not yet started, # successful, failed, or could not be run because of the lack of permissions. module LastBackupState # Status not set. LAST_BACKUP_STATE_UNSPECIFIED = 0 # The first backup has not yet completed FIRST_BACKUP_PENDING = 1 # The most recent backup was successful SUCCEEDED = 2 # The most recent backup failed FAILED = 3 # The most recent backup could not be run/failed because of the lack of # permissions PERMISSION_DENIED = 4 end end |
#last_backup_state ⇒ ::Google::Cloud::BackupDR::V1::BackupConfigInfo::LastBackupState (readonly)
Returns Output only. The status of the last backup to this BackupVault.
306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 |
# File 'proto_docs/google/cloud/backupdr/v1/backupvault.rb', line 306 class BackupConfigInfo include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # LastBackupstate tracks whether the last backup was not yet started, # successful, failed, or could not be run because of the lack of permissions. module LastBackupState # Status not set. LAST_BACKUP_STATE_UNSPECIFIED = 0 # The first backup has not yet completed FIRST_BACKUP_PENDING = 1 # The most recent backup was successful SUCCEEDED = 2 # The most recent backup failed FAILED = 3 # The most recent backup could not be run/failed because of the lack of # permissions PERMISSION_DENIED = 4 end end |
#last_successful_backup_consistency_time ⇒ ::Google::Protobuf::Timestamp (readonly)
Returns Output only. If the last backup were successful, this field has the consistency date.
306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 |
# File 'proto_docs/google/cloud/backupdr/v1/backupvault.rb', line 306 class BackupConfigInfo include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # LastBackupstate tracks whether the last backup was not yet started, # successful, failed, or could not be run because of the lack of permissions. module LastBackupState # Status not set. LAST_BACKUP_STATE_UNSPECIFIED = 0 # The first backup has not yet completed FIRST_BACKUP_PENDING = 1 # The most recent backup was successful SUCCEEDED = 2 # The most recent backup failed FAILED = 3 # The most recent backup could not be run/failed because of the lack of # permissions PERMISSION_DENIED = 4 end end |