Class: Google::Cloud::BackupDR::V1::BackupDrTemplateConfig
- Inherits:
-
Object
- Object
- Google::Cloud::BackupDR::V1::BackupDrTemplateConfig
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/backupdr/v1/protection_summary.rb
Overview
Provides additional information about Google Cloud Backup and DR's Template backup configuration.
Instance Attribute Summary collapse
-
#first_party_management_uri ⇒ ::String
readonly
Output only.
-
#third_party_management_uri ⇒ ::String
readonly
Output only.
Instance Attribute Details
#first_party_management_uri ⇒ ::String (readonly)
Returns Output only. The URI of the BackupDr template resource for the first party identity users.
252 253 254 255 |
# File 'proto_docs/google/cloud/backupdr/v1/protection_summary.rb', line 252 class BackupDrTemplateConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#third_party_management_uri ⇒ ::String (readonly)
Returns Output only. The URI of the BackupDr template resource for the third party identity users.
252 253 254 255 |
# File 'proto_docs/google/cloud/backupdr/v1/protection_summary.rb', line 252 class BackupDrTemplateConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |