Module: Google::Cloud::BackupDR::V1::BackupVault::BackupRetentionInheritance
- Defined in:
- proto_docs/google/cloud/backupdr/v1/backupvault.rb
Overview
How a backup's enforced retention end time is inherited.
Constant Summary collapse
- BACKUP_RETENTION_INHERITANCE_UNSPECIFIED =
Inheritance behavior not set. This will default to
INHERIT_VAULT_RETENTION. 0- INHERIT_VAULT_RETENTION =
The enforced retention end time of a backup will be inherited from the backup vault's
backup_minimum_enforced_retention_durationfield.This is the default behavior.
1- MATCH_BACKUP_EXPIRE_TIME =
The enforced retention end time of a backup will always match the expire time of the backup.
If this is set, the backup's enforced retention end time will be set to match the expire time during creation of the backup. When updating, the ERET and expire time must be updated together and have the same value. Invalid update requests will be rejected by the server.
2