Class: Google::Cloud::BackupDR::V1::GcpBackupConfig

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/backupdr/v1/backupvault.rb

Overview

GcpBackupConfig captures the Backup configuration details for Google Cloud resources. All Google Cloud resources regardless of type are protected with backup plan associations.

Instance Attribute Summary collapse

Instance Attribute Details

#backup_plan::String

Returns The name of the backup plan.

Returns:

  • (::String)

    The name of the backup plan.



351
352
353
354
# File 'proto_docs/google/cloud/backupdr/v1/backupvault.rb', line 351

class GcpBackupConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#backup_plan_association::String

Returns The name of the backup plan association.

Returns:

  • (::String)

    The name of the backup plan association.



351
352
353
354
# File 'proto_docs/google/cloud/backupdr/v1/backupvault.rb', line 351

class GcpBackupConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#backup_plan_description::String

Returns The description of the backup plan.

Returns:

  • (::String)

    The description of the backup plan.



351
352
353
354
# File 'proto_docs/google/cloud/backupdr/v1/backupvault.rb', line 351

class GcpBackupConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#backup_plan_revision_id::String

Returns The user friendly id of the backup plan revision. E.g. v0, v1 etc.

Returns:

  • (::String)

    The user friendly id of the backup plan revision. E.g. v0, v1 etc.



351
352
353
354
# File 'proto_docs/google/cloud/backupdr/v1/backupvault.rb', line 351

class GcpBackupConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#backup_plan_revision_name::String

Returns The name of the backup plan revision.

Returns:

  • (::String)

    The name of the backup plan revision.



351
352
353
354
# File 'proto_docs/google/cloud/backupdr/v1/backupvault.rb', line 351

class GcpBackupConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#backup_plan_rules::Array<::String>

Returns The names of the backup plan rules which point to this backupvault.

Returns:

  • (::Array<::String>)

    The names of the backup plan rules which point to this backupvault



351
352
353
354
# File 'proto_docs/google/cloud/backupdr/v1/backupvault.rb', line 351

class GcpBackupConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end