Class: Google::Cloud::BackupDR::V1::ResourceBackupConfig

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/backupdr/v1/protection_summary.rb

Overview

ResourceBackupConfig represents a resource along with its backup configurations.

Defined Under Namespace

Modules: ResourceType Classes: TargetResourceLabelsEntry

Instance Attribute Summary collapse

Instance Attribute Details

#backup_configs_details::Array<::Google::Cloud::BackupDR::V1::BackupConfigDetails>

Returns Backup configurations applying to the target resource, including those targeting its related/child resources. For example, backup configuration applicable to Compute Engine disks will be populated in this field for a Compute Engine VM which has the disk associated.

Returns:

  • (::Array<::Google::Cloud::BackupDR::V1::BackupConfigDetails>)

    Backup configurations applying to the target resource, including those targeting its related/child resources. For example, backup configuration applicable to Compute Engine disks will be populated in this field for a Compute Engine VM which has the disk associated.



106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
# File 'proto_docs/google/cloud/backupdr/v1/protection_summary.rb', line 106

class ResourceBackupConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class TargetResourceLabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # The type of the cloud resource.
  module ResourceType
    # Resource type not set.
    RESOURCE_TYPE_UNSPECIFIED = 0

    # Cloud SQL instance.
    CLOUD_SQL_INSTANCE = 1

    # Compute Engine VM.
    COMPUTE_ENGINE_VM = 2

    # Compute Engine Disk.
    COMPUTE_ENGINE_DISK = 3

    # Compute Engine Regional Disk.
    COMPUTE_ENGINE_REGIONAL_DISK = 4
  end
end

#backup_configured::Boolean (readonly)

Returns Output only. Whether the target resource is configured for backup. This is true if the backup_configs_details is not empty.

Returns:

  • (::Boolean)

    Output only. Whether the target resource is configured for backup. This is true if the backup_configs_details is not empty.



106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
# File 'proto_docs/google/cloud/backupdr/v1/protection_summary.rb', line 106

class ResourceBackupConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class TargetResourceLabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # The type of the cloud resource.
  module ResourceType
    # Resource type not set.
    RESOURCE_TYPE_UNSPECIFIED = 0

    # Cloud SQL instance.
    CLOUD_SQL_INSTANCE = 1

    # Compute Engine VM.
    COMPUTE_ENGINE_VM = 2

    # Compute Engine Disk.
    COMPUTE_ENGINE_DISK = 3

    # Compute Engine Regional Disk.
    COMPUTE_ENGINE_REGIONAL_DISK = 4
  end
end

#name::String

Returns Identifier. The resource name of the ResourceBackupConfig. Format: projects/{project}/locations/{location}/resourceBackupConfigs/{uid}.

Returns:

  • (::String)

    Identifier. The resource name of the ResourceBackupConfig. Format: projects/{project}/locations/{location}/resourceBackupConfigs/{uid}



106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
# File 'proto_docs/google/cloud/backupdr/v1/protection_summary.rb', line 106

class ResourceBackupConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class TargetResourceLabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # The type of the cloud resource.
  module ResourceType
    # Resource type not set.
    RESOURCE_TYPE_UNSPECIFIED = 0

    # Cloud SQL instance.
    CLOUD_SQL_INSTANCE = 1

    # Compute Engine VM.
    COMPUTE_ENGINE_VM = 2

    # Compute Engine Disk.
    COMPUTE_ENGINE_DISK = 3

    # Compute Engine Regional Disk.
    COMPUTE_ENGINE_REGIONAL_DISK = 4
  end
end

#target_resource::String (readonly)

Returns Output only. The full resource name of the cloud resource that this configuration applies to. Supported resource types are ResourceBackupConfig.ResourceType.

Returns:



106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
# File 'proto_docs/google/cloud/backupdr/v1/protection_summary.rb', line 106

class ResourceBackupConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class TargetResourceLabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # The type of the cloud resource.
  module ResourceType
    # Resource type not set.
    RESOURCE_TYPE_UNSPECIFIED = 0

    # Cloud SQL instance.
    CLOUD_SQL_INSTANCE = 1

    # Compute Engine VM.
    COMPUTE_ENGINE_VM = 2

    # Compute Engine Disk.
    COMPUTE_ENGINE_DISK = 3

    # Compute Engine Regional Disk.
    COMPUTE_ENGINE_REGIONAL_DISK = 4
  end
end

#target_resource_display_name::String (readonly)

Returns Output only. The human friendly name of the target resource.

Returns:

  • (::String)

    Output only. The human friendly name of the target resource.



106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
# File 'proto_docs/google/cloud/backupdr/v1/protection_summary.rb', line 106

class ResourceBackupConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class TargetResourceLabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # The type of the cloud resource.
  module ResourceType
    # Resource type not set.
    RESOURCE_TYPE_UNSPECIFIED = 0

    # Cloud SQL instance.
    CLOUD_SQL_INSTANCE = 1

    # Compute Engine VM.
    COMPUTE_ENGINE_VM = 2

    # Compute Engine Disk.
    COMPUTE_ENGINE_DISK = 3

    # Compute Engine Regional Disk.
    COMPUTE_ENGINE_REGIONAL_DISK = 4
  end
end

#target_resource_labels::Google::Protobuf::Map{::String => ::String}

Returns Labels associated with the target resource.

Returns:

  • (::Google::Protobuf::Map{::String => ::String})

    Labels associated with the target resource.



106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
# File 'proto_docs/google/cloud/backupdr/v1/protection_summary.rb', line 106

class ResourceBackupConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class TargetResourceLabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # The type of the cloud resource.
  module ResourceType
    # Resource type not set.
    RESOURCE_TYPE_UNSPECIFIED = 0

    # Cloud SQL instance.
    CLOUD_SQL_INSTANCE = 1

    # Compute Engine VM.
    COMPUTE_ENGINE_VM = 2

    # Compute Engine Disk.
    COMPUTE_ENGINE_DISK = 3

    # Compute Engine Regional Disk.
    COMPUTE_ENGINE_REGIONAL_DISK = 4
  end
end

#target_resource_type::Google::Cloud::BackupDR::V1::ResourceBackupConfig::ResourceType (readonly)

Returns Output only. The type of the target resource.

Returns:



106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
# File 'proto_docs/google/cloud/backupdr/v1/protection_summary.rb', line 106

class ResourceBackupConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class TargetResourceLabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # The type of the cloud resource.
  module ResourceType
    # Resource type not set.
    RESOURCE_TYPE_UNSPECIFIED = 0

    # Cloud SQL instance.
    CLOUD_SQL_INSTANCE = 1

    # Compute Engine VM.
    COMPUTE_ENGINE_VM = 2

    # Compute Engine Disk.
    COMPUTE_ENGINE_DISK = 3

    # Compute Engine Regional Disk.
    COMPUTE_ENGINE_REGIONAL_DISK = 4
  end
end

#uid::String (readonly)

Returns Output only. The unique identifier of the resource backup config.

Returns:

  • (::String)

    Output only. The unique identifier of the resource backup config.



106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
# File 'proto_docs/google/cloud/backupdr/v1/protection_summary.rb', line 106

class ResourceBackupConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class TargetResourceLabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # The type of the cloud resource.
  module ResourceType
    # Resource type not set.
    RESOURCE_TYPE_UNSPECIFIED = 0

    # Cloud SQL instance.
    CLOUD_SQL_INSTANCE = 1

    # Compute Engine VM.
    COMPUTE_ENGINE_VM = 2

    # Compute Engine Disk.
    COMPUTE_ENGINE_DISK = 3

    # Compute Engine Regional Disk.
    COMPUTE_ENGINE_REGIONAL_DISK = 4
  end
end

#vaulted::Boolean (readonly)

Returns Output only. Whether the target resource is protected by a backup vault. This is true if the backup_configs_details is not empty and any of the ResourceBackupConfig.backup_configs_details has a backup configuration with BackupConfigDetails.backup_vault set. set.

Returns:



106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
# File 'proto_docs/google/cloud/backupdr/v1/protection_summary.rb', line 106

class ResourceBackupConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class TargetResourceLabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # The type of the cloud resource.
  module ResourceType
    # Resource type not set.
    RESOURCE_TYPE_UNSPECIFIED = 0

    # Cloud SQL instance.
    CLOUD_SQL_INSTANCE = 1

    # Compute Engine VM.
    COMPUTE_ENGINE_VM = 2

    # Compute Engine Disk.
    COMPUTE_ENGINE_DISK = 3

    # Compute Engine Regional Disk.
    COMPUTE_ENGINE_REGIONAL_DISK = 4
  end
end