Class: Google::Cloud::BackupDR::V1::RestoreBackupRequest
- Inherits:
-
Object
- Object
- Google::Cloud::BackupDR::V1::RestoreBackupRequest
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/backupdr/v1/backupvault.rb
Overview
Request message for restoring from a Backup.
Instance Attribute Summary collapse
-
#clear_overrides_field_mask ⇒ ::Google::Protobuf::FieldMask
Optional.
-
#compute_instance_restore_properties ⇒ ::Google::Cloud::BackupDR::V1::ComputeInstanceRestoreProperties
Compute Engine instance properties to be overridden during restore.
-
#compute_instance_target_environment ⇒ ::Google::Cloud::BackupDR::V1::ComputeInstanceTargetEnvironment
Compute Engine target environment to be used during restore.
-
#disk_restore_properties ⇒ ::Google::Cloud::BackupDR::V1::DiskRestoreProperties
Disk properties to be overridden during restore.
-
#disk_target_environment ⇒ ::Google::Cloud::BackupDR::V1::DiskTargetEnvironment
Disk target environment to be used during restore.
-
#name ⇒ ::String
Required.
-
#region_disk_target_environment ⇒ ::Google::Cloud::BackupDR::V1::RegionDiskTargetEnvironment
Region disk target environment to be used during restore.
-
#request_id ⇒ ::String
Optional.
Instance Attribute Details
#clear_overrides_field_mask ⇒ ::Google::Protobuf::FieldMask
Returns Optional. A field mask used to clear server-side default values
for fields within the instance_properties oneof.
When a field in this mask is cleared, the server will not apply its default logic (like inheriting a value from the source) for that field.
The most common current use case is clearing default encryption keys.
Examples of field mask paths:
- Compute Instance Disks:
compute_instance_restore_properties.disks.*.disk_encryption_key - Single Disk:
disk_restore_properties.disk_encryption_key.
1269 1270 1271 1272 |
# File 'proto_docs/google/cloud/backupdr/v1/backupvault.rb', line 1269 class RestoreBackupRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#compute_instance_restore_properties ⇒ ::Google::Cloud::BackupDR::V1::ComputeInstanceRestoreProperties
Returns Compute Engine instance properties to be overridden during restore.
Note: The following fields are mutually exclusive: compute_instance_restore_properties, disk_restore_properties. If a field in that set is populated, all other fields in the set will automatically be cleared.
1269 1270 1271 1272 |
# File 'proto_docs/google/cloud/backupdr/v1/backupvault.rb', line 1269 class RestoreBackupRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#compute_instance_target_environment ⇒ ::Google::Cloud::BackupDR::V1::ComputeInstanceTargetEnvironment
Returns Compute Engine target environment to be used during restore.
Note: The following fields are mutually exclusive: compute_instance_target_environment, disk_target_environment, region_disk_target_environment. If a field in that set is populated, all other fields in the set will automatically be cleared.
1269 1270 1271 1272 |
# File 'proto_docs/google/cloud/backupdr/v1/backupvault.rb', line 1269 class RestoreBackupRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#disk_restore_properties ⇒ ::Google::Cloud::BackupDR::V1::DiskRestoreProperties
Returns Disk properties to be overridden during restore.
Note: The following fields are mutually exclusive: disk_restore_properties, compute_instance_restore_properties. If a field in that set is populated, all other fields in the set will automatically be cleared.
1269 1270 1271 1272 |
# File 'proto_docs/google/cloud/backupdr/v1/backupvault.rb', line 1269 class RestoreBackupRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#disk_target_environment ⇒ ::Google::Cloud::BackupDR::V1::DiskTargetEnvironment
Returns Disk target environment to be used during restore.
Note: The following fields are mutually exclusive: disk_target_environment, compute_instance_target_environment, region_disk_target_environment. If a field in that set is populated, all other fields in the set will automatically be cleared.
1269 1270 1271 1272 |
# File 'proto_docs/google/cloud/backupdr/v1/backupvault.rb', line 1269 class RestoreBackupRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#name ⇒ ::String
Returns Required. The resource name of the Backup instance, in the format 'projects//locations//backupVaults//dataSources//backups/'.
1269 1270 1271 1272 |
# File 'proto_docs/google/cloud/backupdr/v1/backupvault.rb', line 1269 class RestoreBackupRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#region_disk_target_environment ⇒ ::Google::Cloud::BackupDR::V1::RegionDiskTargetEnvironment
Returns Region disk target environment to be used during restore.
Note: The following fields are mutually exclusive: region_disk_target_environment, compute_instance_target_environment, disk_target_environment. If a field in that set is populated, all other fields in the set will automatically be cleared.
1269 1270 1271 1272 |
# File 'proto_docs/google/cloud/backupdr/v1/backupvault.rb', line 1269 class RestoreBackupRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#request_id ⇒ ::String
Returns Optional. An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. The server will guarantee that for at least 60 minutes after the first request.
For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments.
The request ID must be a valid UUID with the exception that zero UUID is not supported (00000000-0000-0000-0000-000000000000).
1269 1270 1271 1272 |
# File 'proto_docs/google/cloud/backupdr/v1/backupvault.rb', line 1269 class RestoreBackupRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |