Class: Google::Cloud::BackupDR::V1::BackupConfigDetails
- Inherits:
-
Object
- Object
- Google::Cloud::BackupDR::V1::BackupConfigDetails
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/backupdr/v1/protection_summary.rb
Overview
BackupConfigDetails has information about how the resource is configured for backups and about the most recent backup taken for this configuration.
Defined Under Namespace
Instance Attribute Summary collapse
-
#applicable_resource ⇒ ::String
readonly
Output only.
-
#backup_config_source ⇒ ::String
readonly
Output only.
-
#backup_config_source_display_name ⇒ ::String
readonly
Output only.
-
#backup_dr_plan_config ⇒ ::Google::Cloud::BackupDR::V1::BackupDrPlanConfig
Google Cloud Backup and DR's Backup Plan specific data.
-
#backup_dr_template_config ⇒ ::Google::Cloud::BackupDR::V1::BackupDrTemplateConfig
Google Cloud Backup and DR's Template specific data.
-
#backup_locations ⇒ ::Array<::Google::Cloud::BackupDR::V1::BackupLocation>
The locations where the backups are to be stored.
-
#backup_vault ⇒ ::String
readonly
Output only.
-
#latest_successful_backup_time ⇒ ::Google::Protobuf::Timestamp
readonly
Output only.
-
#pitr_settings ⇒ ::Google::Cloud::BackupDR::V1::PitrSettings
readonly
Output only.
-
#state ⇒ ::Google::Cloud::BackupDR::V1::BackupConfigDetails::State
readonly
Output only.
-
#type ⇒ ::Google::Cloud::BackupDR::V1::BackupConfigDetails::Type
readonly
Output only.
Instance Attribute Details
#applicable_resource ⇒ ::String (readonly)
Returns Output only. The full resource name of the resource that is applicable for the backup configuration. Example: "//compute.googleapis.com/projects/{project}/zones/{zone}/instances/{instance}".
190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 |
# File 'proto_docs/google/cloud/backupdr/v1/protection_summary.rb', line 190 class BackupConfigDetails include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Type of the backup configuration. # This enum may receive new values in the future. module Type # Backup config type is unspecified. TYPE_UNSPECIFIED = 0 # Backup config is Cloud SQL instance's automated backup config. CLOUD_SQL_INSTANCE_BACKUP_CONFIG = 1 # Backup config is Compute Engine Resource Policy. COMPUTE_ENGINE_RESOURCE_POLICY = 2 # Backup config is Google Cloud Backup and DR's Backup Plan. BACKUPDR_BACKUP_PLAN = 3 # Backup config is Google Cloud Backup and DR's Template. BACKUPDR_TEMPLATE = 4 end # The state tells whether the backup config is active or not. module State # Backup config state not set. STATE_UNSPECIFIED = 0 # The config is in an active state protecting the resource ACTIVE = 1 # The config is currently not protecting the resource. Either because it is # disabled or the owning project has been deleted without cleanup of the # actual resource. INACTIVE = 2 # The config still exists but because of some error state it is not # protecting the resource. Like the source project is deleted. For eg. # PlanAssociation, BackupPlan is deleted. ERROR = 3 end end |
#backup_config_source ⇒ ::String (readonly)
Returns Output only. The full resource name of the backup config source resource. For example, "//backupdr.googleapis.com/v1/projects/{project}/locations/{region}/backupPlans/{backupplanId}" or "//compute.googleapis.com/projects/{project}/locations/{region}/resourcePolicies/{resourcePolicyId}".
190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 |
# File 'proto_docs/google/cloud/backupdr/v1/protection_summary.rb', line 190 class BackupConfigDetails include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Type of the backup configuration. # This enum may receive new values in the future. module Type # Backup config type is unspecified. TYPE_UNSPECIFIED = 0 # Backup config is Cloud SQL instance's automated backup config. CLOUD_SQL_INSTANCE_BACKUP_CONFIG = 1 # Backup config is Compute Engine Resource Policy. COMPUTE_ENGINE_RESOURCE_POLICY = 2 # Backup config is Google Cloud Backup and DR's Backup Plan. BACKUPDR_BACKUP_PLAN = 3 # Backup config is Google Cloud Backup and DR's Template. BACKUPDR_TEMPLATE = 4 end # The state tells whether the backup config is active or not. module State # Backup config state not set. STATE_UNSPECIFIED = 0 # The config is in an active state protecting the resource ACTIVE = 1 # The config is currently not protecting the resource. Either because it is # disabled or the owning project has been deleted without cleanup of the # actual resource. INACTIVE = 2 # The config still exists but because of some error state it is not # protecting the resource. Like the source project is deleted. For eg. # PlanAssociation, BackupPlan is deleted. ERROR = 3 end end |
#backup_config_source_display_name ⇒ ::String (readonly)
Returns Output only. The display name of the backup config source resource.
190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 |
# File 'proto_docs/google/cloud/backupdr/v1/protection_summary.rb', line 190 class BackupConfigDetails include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Type of the backup configuration. # This enum may receive new values in the future. module Type # Backup config type is unspecified. TYPE_UNSPECIFIED = 0 # Backup config is Cloud SQL instance's automated backup config. CLOUD_SQL_INSTANCE_BACKUP_CONFIG = 1 # Backup config is Compute Engine Resource Policy. COMPUTE_ENGINE_RESOURCE_POLICY = 2 # Backup config is Google Cloud Backup and DR's Backup Plan. BACKUPDR_BACKUP_PLAN = 3 # Backup config is Google Cloud Backup and DR's Template. BACKUPDR_TEMPLATE = 4 end # The state tells whether the backup config is active or not. module State # Backup config state not set. STATE_UNSPECIFIED = 0 # The config is in an active state protecting the resource ACTIVE = 1 # The config is currently not protecting the resource. Either because it is # disabled or the owning project has been deleted without cleanup of the # actual resource. INACTIVE = 2 # The config still exists but because of some error state it is not # protecting the resource. Like the source project is deleted. For eg. # PlanAssociation, BackupPlan is deleted. ERROR = 3 end end |
#backup_dr_plan_config ⇒ ::Google::Cloud::BackupDR::V1::BackupDrPlanConfig
Returns Google Cloud Backup and DR's Backup Plan specific data.
Note: The following fields are mutually exclusive: backup_dr_plan_config, backup_dr_template_config. If a field in that set is populated, all other fields in the set will automatically be cleared.
190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 |
# File 'proto_docs/google/cloud/backupdr/v1/protection_summary.rb', line 190 class BackupConfigDetails include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Type of the backup configuration. # This enum may receive new values in the future. module Type # Backup config type is unspecified. TYPE_UNSPECIFIED = 0 # Backup config is Cloud SQL instance's automated backup config. CLOUD_SQL_INSTANCE_BACKUP_CONFIG = 1 # Backup config is Compute Engine Resource Policy. COMPUTE_ENGINE_RESOURCE_POLICY = 2 # Backup config is Google Cloud Backup and DR's Backup Plan. BACKUPDR_BACKUP_PLAN = 3 # Backup config is Google Cloud Backup and DR's Template. BACKUPDR_TEMPLATE = 4 end # The state tells whether the backup config is active or not. module State # Backup config state not set. STATE_UNSPECIFIED = 0 # The config is in an active state protecting the resource ACTIVE = 1 # The config is currently not protecting the resource. Either because it is # disabled or the owning project has been deleted without cleanup of the # actual resource. INACTIVE = 2 # The config still exists but because of some error state it is not # protecting the resource. Like the source project is deleted. For eg. # PlanAssociation, BackupPlan is deleted. ERROR = 3 end end |
#backup_dr_template_config ⇒ ::Google::Cloud::BackupDR::V1::BackupDrTemplateConfig
Returns Google Cloud Backup and DR's Template specific data.
Note: The following fields are mutually exclusive: backup_dr_template_config, backup_dr_plan_config. If a field in that set is populated, all other fields in the set will automatically be cleared.
190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 |
# File 'proto_docs/google/cloud/backupdr/v1/protection_summary.rb', line 190 class BackupConfigDetails include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Type of the backup configuration. # This enum may receive new values in the future. module Type # Backup config type is unspecified. TYPE_UNSPECIFIED = 0 # Backup config is Cloud SQL instance's automated backup config. CLOUD_SQL_INSTANCE_BACKUP_CONFIG = 1 # Backup config is Compute Engine Resource Policy. COMPUTE_ENGINE_RESOURCE_POLICY = 2 # Backup config is Google Cloud Backup and DR's Backup Plan. BACKUPDR_BACKUP_PLAN = 3 # Backup config is Google Cloud Backup and DR's Template. BACKUPDR_TEMPLATE = 4 end # The state tells whether the backup config is active or not. module State # Backup config state not set. STATE_UNSPECIFIED = 0 # The config is in an active state protecting the resource ACTIVE = 1 # The config is currently not protecting the resource. Either because it is # disabled or the owning project has been deleted without cleanup of the # actual resource. INACTIVE = 2 # The config still exists but because of some error state it is not # protecting the resource. Like the source project is deleted. For eg. # PlanAssociation, BackupPlan is deleted. ERROR = 3 end end |
#backup_locations ⇒ ::Array<::Google::Cloud::BackupDR::V1::BackupLocation>
Returns The locations where the backups are to be stored.
190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 |
# File 'proto_docs/google/cloud/backupdr/v1/protection_summary.rb', line 190 class BackupConfigDetails include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Type of the backup configuration. # This enum may receive new values in the future. module Type # Backup config type is unspecified. TYPE_UNSPECIFIED = 0 # Backup config is Cloud SQL instance's automated backup config. CLOUD_SQL_INSTANCE_BACKUP_CONFIG = 1 # Backup config is Compute Engine Resource Policy. COMPUTE_ENGINE_RESOURCE_POLICY = 2 # Backup config is Google Cloud Backup and DR's Backup Plan. BACKUPDR_BACKUP_PLAN = 3 # Backup config is Google Cloud Backup and DR's Template. BACKUPDR_TEMPLATE = 4 end # The state tells whether the backup config is active or not. module State # Backup config state not set. STATE_UNSPECIFIED = 0 # The config is in an active state protecting the resource ACTIVE = 1 # The config is currently not protecting the resource. Either because it is # disabled or the owning project has been deleted without cleanup of the # actual resource. INACTIVE = 2 # The config still exists but because of some error state it is not # protecting the resource. Like the source project is deleted. For eg. # PlanAssociation, BackupPlan is deleted. ERROR = 3 end end |
#backup_vault ⇒ ::String (readonly)
Returns Output only. The full resource name of the backup vault that will store the backups generated through this backup configuration. Example: "//backupdr.googleapis.com/v1/projects/{project}/locations/{region}/backupVaults/{backupvaultId}".
190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 |
# File 'proto_docs/google/cloud/backupdr/v1/protection_summary.rb', line 190 class BackupConfigDetails include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Type of the backup configuration. # This enum may receive new values in the future. module Type # Backup config type is unspecified. TYPE_UNSPECIFIED = 0 # Backup config is Cloud SQL instance's automated backup config. CLOUD_SQL_INSTANCE_BACKUP_CONFIG = 1 # Backup config is Compute Engine Resource Policy. COMPUTE_ENGINE_RESOURCE_POLICY = 2 # Backup config is Google Cloud Backup and DR's Backup Plan. BACKUPDR_BACKUP_PLAN = 3 # Backup config is Google Cloud Backup and DR's Template. BACKUPDR_TEMPLATE = 4 end # The state tells whether the backup config is active or not. module State # Backup config state not set. STATE_UNSPECIFIED = 0 # The config is in an active state protecting the resource ACTIVE = 1 # The config is currently not protecting the resource. Either because it is # disabled or the owning project has been deleted without cleanup of the # actual resource. INACTIVE = 2 # The config still exists but because of some error state it is not # protecting the resource. Like the source project is deleted. For eg. # PlanAssociation, BackupPlan is deleted. ERROR = 3 end end |
#latest_successful_backup_time ⇒ ::Google::Protobuf::Timestamp (readonly)
Returns Output only. Timestamp of the latest successful backup created via this backup configuration.
190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 |
# File 'proto_docs/google/cloud/backupdr/v1/protection_summary.rb', line 190 class BackupConfigDetails include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Type of the backup configuration. # This enum may receive new values in the future. module Type # Backup config type is unspecified. TYPE_UNSPECIFIED = 0 # Backup config is Cloud SQL instance's automated backup config. CLOUD_SQL_INSTANCE_BACKUP_CONFIG = 1 # Backup config is Compute Engine Resource Policy. COMPUTE_ENGINE_RESOURCE_POLICY = 2 # Backup config is Google Cloud Backup and DR's Backup Plan. BACKUPDR_BACKUP_PLAN = 3 # Backup config is Google Cloud Backup and DR's Template. BACKUPDR_TEMPLATE = 4 end # The state tells whether the backup config is active or not. module State # Backup config state not set. STATE_UNSPECIFIED = 0 # The config is in an active state protecting the resource ACTIVE = 1 # The config is currently not protecting the resource. Either because it is # disabled or the owning project has been deleted without cleanup of the # actual resource. INACTIVE = 2 # The config still exists but because of some error state it is not # protecting the resource. Like the source project is deleted. For eg. # PlanAssociation, BackupPlan is deleted. ERROR = 3 end end |
#pitr_settings ⇒ ::Google::Cloud::BackupDR::V1::PitrSettings (readonly)
Returns Output only. Point in time recovery settings of the backup configuration resource.
190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 |
# File 'proto_docs/google/cloud/backupdr/v1/protection_summary.rb', line 190 class BackupConfigDetails include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Type of the backup configuration. # This enum may receive new values in the future. module Type # Backup config type is unspecified. TYPE_UNSPECIFIED = 0 # Backup config is Cloud SQL instance's automated backup config. CLOUD_SQL_INSTANCE_BACKUP_CONFIG = 1 # Backup config is Compute Engine Resource Policy. COMPUTE_ENGINE_RESOURCE_POLICY = 2 # Backup config is Google Cloud Backup and DR's Backup Plan. BACKUPDR_BACKUP_PLAN = 3 # Backup config is Google Cloud Backup and DR's Template. BACKUPDR_TEMPLATE = 4 end # The state tells whether the backup config is active or not. module State # Backup config state not set. STATE_UNSPECIFIED = 0 # The config is in an active state protecting the resource ACTIVE = 1 # The config is currently not protecting the resource. Either because it is # disabled or the owning project has been deleted without cleanup of the # actual resource. INACTIVE = 2 # The config still exists but because of some error state it is not # protecting the resource. Like the source project is deleted. For eg. # PlanAssociation, BackupPlan is deleted. ERROR = 3 end end |
#state ⇒ ::Google::Cloud::BackupDR::V1::BackupConfigDetails::State (readonly)
Returns Output only. The state of the backup config resource.
190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 |
# File 'proto_docs/google/cloud/backupdr/v1/protection_summary.rb', line 190 class BackupConfigDetails include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Type of the backup configuration. # This enum may receive new values in the future. module Type # Backup config type is unspecified. TYPE_UNSPECIFIED = 0 # Backup config is Cloud SQL instance's automated backup config. CLOUD_SQL_INSTANCE_BACKUP_CONFIG = 1 # Backup config is Compute Engine Resource Policy. COMPUTE_ENGINE_RESOURCE_POLICY = 2 # Backup config is Google Cloud Backup and DR's Backup Plan. BACKUPDR_BACKUP_PLAN = 3 # Backup config is Google Cloud Backup and DR's Template. BACKUPDR_TEMPLATE = 4 end # The state tells whether the backup config is active or not. module State # Backup config state not set. STATE_UNSPECIFIED = 0 # The config is in an active state protecting the resource ACTIVE = 1 # The config is currently not protecting the resource. Either because it is # disabled or the owning project has been deleted without cleanup of the # actual resource. INACTIVE = 2 # The config still exists but because of some error state it is not # protecting the resource. Like the source project is deleted. For eg. # PlanAssociation, BackupPlan is deleted. ERROR = 3 end end |
#type ⇒ ::Google::Cloud::BackupDR::V1::BackupConfigDetails::Type (readonly)
Returns Output only. The type of the backup config resource.
190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 |
# File 'proto_docs/google/cloud/backupdr/v1/protection_summary.rb', line 190 class BackupConfigDetails include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Type of the backup configuration. # This enum may receive new values in the future. module Type # Backup config type is unspecified. TYPE_UNSPECIFIED = 0 # Backup config is Cloud SQL instance's automated backup config. CLOUD_SQL_INSTANCE_BACKUP_CONFIG = 1 # Backup config is Compute Engine Resource Policy. COMPUTE_ENGINE_RESOURCE_POLICY = 2 # Backup config is Google Cloud Backup and DR's Backup Plan. BACKUPDR_BACKUP_PLAN = 3 # Backup config is Google Cloud Backup and DR's Template. BACKUPDR_TEMPLATE = 4 end # The state tells whether the backup config is active or not. module State # Backup config state not set. STATE_UNSPECIFIED = 0 # The config is in an active state protecting the resource ACTIVE = 1 # The config is currently not protecting the resource. Either because it is # disabled or the owning project has been deleted without cleanup of the # actual resource. INACTIVE = 2 # The config still exists but because of some error state it is not # protecting the resource. Like the source project is deleted. For eg. # PlanAssociation, BackupPlan is deleted. ERROR = 3 end end |