Class: Google::Cloud::BackupDR::V1::BackupDrPlanRule
- Inherits:
-
Object
- Object
- Google::Cloud::BackupDR::V1::BackupDrPlanRule
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/backupdr/v1/protection_summary.rb
Overview
BackupDrPlanRule has rule specific information of the backup plan resource.
Instance Attribute Summary collapse
-
#last_successful_backup_time ⇒ ::Google::Protobuf::Timestamp
readonly
Output only.
-
#rule_id ⇒ ::String
readonly
Output only.
Instance Attribute Details
#last_successful_backup_time ⇒ ::Google::Protobuf::Timestamp (readonly)
Returns Output only. Timestamp of the latest successful backup created via this backup rule.
275 276 277 278 |
# File 'proto_docs/google/cloud/backupdr/v1/protection_summary.rb', line 275 class BackupDrPlanRule include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#rule_id ⇒ ::String (readonly)
Returns Output only. Unique Id of the backup rule.
275 276 277 278 |
# File 'proto_docs/google/cloud/backupdr/v1/protection_summary.rb', line 275 class BackupDrPlanRule include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |