Class: Google::Cloud::BackupDR::V1::BackupVault::EncryptionConfig

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/backupdr/v1/backupvault.rb

Overview

Message describing the EncryptionConfig of backup vault. This determines how data within the vault is encrypted at rest.

Instance Attribute Summary collapse

Instance Attribute Details

#kms_key_name::String

Returns Optional. The Cloud KMS key name to encrypt backups in this backup vault. Must be in the same region as the vault. Some workload backups like compute disk backups may use their inherited source key instead. Format: projects/{project}/locations/{location}/keyRings/{ring}/cryptoKeys/{key}.

Returns:

  • (::String)

    Optional. The Cloud KMS key name to encrypt backups in this backup vault. Must be in the same region as the vault. Some workload backups like compute disk backups may use their inherited source key instead. Format: projects/{project}/locations/{location}/keyRings/{ring}/cryptoKeys/{key}



108
109
110
111
# File 'proto_docs/google/cloud/backupdr/v1/backupvault.rb', line 108

class EncryptionConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end