Class: Google::Cloud::BackupDR::V1::DataSource

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/backupdr/v1/backupvault.rb

Overview

Message describing a DataSource object. Datasource object used to represent Datasource details for both admin and basic view.

Defined Under Namespace

Modules: State Classes: LabelsEntry

Instance Attribute Summary collapse

Instance Attribute Details

#backup_blocked_by_vault_access_restriction::Boolean (readonly)

Returns Output only. This field is set to true if the backup is blocked by vault access restriction.

Returns:

  • (::Boolean)

    Output only. This field is set to true if the backup is blocked by vault access restriction.



252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
# File 'proto_docs/google/cloud/backupdr/v1/backupvault.rb', line 252

class DataSource
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Holds the state of the data source resource.
  module State
    # State not set.
    STATE_UNSPECIFIED = 0

    # The data source is being created.
    CREATING = 1

    # The data source has been created and is fully usable.
    ACTIVE = 2

    # The data source is being deleted.
    DELETING = 3

    # The data source is experiencing an issue and might be unusable.
    ERROR = 4
  end
end

#backup_config_info::Google::Cloud::BackupDR::V1::BackupConfigInfo (readonly)

Returns Output only. Details of how the resource is configured for backup.

Returns:



252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
# File 'proto_docs/google/cloud/backupdr/v1/backupvault.rb', line 252

class DataSource
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Holds the state of the data source resource.
  module State
    # State not set.
    STATE_UNSPECIFIED = 0

    # The data source is being created.
    CREATING = 1

    # The data source has been created and is fully usable.
    ACTIVE = 2

    # The data source is being deleted.
    DELETING = 3

    # The data source is experiencing an issue and might be unusable.
    ERROR = 4
  end
end

#backup_count::Integer

Returns Number of backups in the data source.

Returns:

  • (::Integer)

    Number of backups in the data source.



252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
# File 'proto_docs/google/cloud/backupdr/v1/backupvault.rb', line 252

class DataSource
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Holds the state of the data source resource.
  module State
    # State not set.
    STATE_UNSPECIFIED = 0

    # The data source is being created.
    CREATING = 1

    # The data source has been created and is fully usable.
    ACTIVE = 2

    # The data source is being deleted.
    DELETING = 3

    # The data source is experiencing an issue and might be unusable.
    ERROR = 4
  end
end

#config_state::Google::Cloud::BackupDR::V1::BackupConfigState (readonly)

Returns Output only. The backup configuration state.

Returns:



252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
# File 'proto_docs/google/cloud/backupdr/v1/backupvault.rb', line 252

class DataSource
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Holds the state of the data source resource.
  module State
    # State not set.
    STATE_UNSPECIFIED = 0

    # The data source is being created.
    CREATING = 1

    # The data source has been created and is fully usable.
    ACTIVE = 2

    # The data source is being deleted.
    DELETING = 3

    # The data source is experiencing an issue and might be unusable.
    ERROR = 4
  end
end

#create_time::Google::Protobuf::Timestamp (readonly)

Returns Output only. The time when the instance was created.

Returns:



252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
# File 'proto_docs/google/cloud/backupdr/v1/backupvault.rb', line 252

class DataSource
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Holds the state of the data source resource.
  module State
    # State not set.
    STATE_UNSPECIFIED = 0

    # The data source is being created.
    CREATING = 1

    # The data source has been created and is fully usable.
    ACTIVE = 2

    # The data source is being deleted.
    DELETING = 3

    # The data source is experiencing an issue and might be unusable.
    ERROR = 4
  end
end

#data_source_backup_appliance_application::Google::Cloud::BackupDR::V1::DataSourceBackupApplianceApplication

Returns The backed up resource is a backup appliance application.

Note: The following fields are mutually exclusive: data_source_backup_appliance_application, data_source_gcp_resource. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:

  • (::Google::Cloud::BackupDR::V1::DataSourceBackupApplianceApplication)

    The backed up resource is a backup appliance application.

    Note: The following fields are mutually exclusive: data_source_backup_appliance_application, data_source_gcp_resource. If a field in that set is populated, all other fields in the set will automatically be cleared.



252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
# File 'proto_docs/google/cloud/backupdr/v1/backupvault.rb', line 252

class DataSource
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Holds the state of the data source resource.
  module State
    # State not set.
    STATE_UNSPECIFIED = 0

    # The data source is being created.
    CREATING = 1

    # The data source has been created and is fully usable.
    ACTIVE = 2

    # The data source is being deleted.
    DELETING = 3

    # The data source is experiencing an issue and might be unusable.
    ERROR = 4
  end
end

#data_source_gcp_resource::Google::Cloud::BackupDR::V1::DataSourceGcpResource

Returns The backed up resource is a Google Cloud resource. The word 'DataSource' was included in the names to indicate that this is the representation of the Google Cloud resource used within the DataSource object.

Note: The following fields are mutually exclusive: data_source_gcp_resource, data_source_backup_appliance_application. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:

  • (::Google::Cloud::BackupDR::V1::DataSourceGcpResource)

    The backed up resource is a Google Cloud resource. The word 'DataSource' was included in the names to indicate that this is the representation of the Google Cloud resource used within the DataSource object.

    Note: The following fields are mutually exclusive: data_source_gcp_resource, data_source_backup_appliance_application. If a field in that set is populated, all other fields in the set will automatically be cleared.



252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
# File 'proto_docs/google/cloud/backupdr/v1/backupvault.rb', line 252

class DataSource
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Holds the state of the data source resource.
  module State
    # State not set.
    STATE_UNSPECIFIED = 0

    # The data source is being created.
    CREATING = 1

    # The data source has been created and is fully usable.
    ACTIVE = 2

    # The data source is being deleted.
    DELETING = 3

    # The data source is experiencing an issue and might be unusable.
    ERROR = 4
  end
end

#etag::String

Returns Server specified ETag for the ManagementServer resource to prevent simultaneous updates from overwiting each other.

Returns:

  • (::String)

    Server specified ETag for the ManagementServer resource to prevent simultaneous updates from overwiting each other.



252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
# File 'proto_docs/google/cloud/backupdr/v1/backupvault.rb', line 252

class DataSource
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Holds the state of the data source resource.
  module State
    # State not set.
    STATE_UNSPECIFIED = 0

    # The data source is being created.
    CREATING = 1

    # The data source has been created and is fully usable.
    ACTIVE = 2

    # The data source is being deleted.
    DELETING = 3

    # The data source is experiencing an issue and might be unusable.
    ERROR = 4
  end
end

#labels::Google::Protobuf::Map{::String => ::String}

Returns Optional. Resource labels to represent user provided metadata. No labels currently defined:.

Returns:

  • (::Google::Protobuf::Map{::String => ::String})

    Optional. Resource labels to represent user provided metadata. No labels currently defined:



252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
# File 'proto_docs/google/cloud/backupdr/v1/backupvault.rb', line 252

class DataSource
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Holds the state of the data source resource.
  module State
    # State not set.
    STATE_UNSPECIFIED = 0

    # The data source is being created.
    CREATING = 1

    # The data source has been created and is fully usable.
    ACTIVE = 2

    # The data source is being deleted.
    DELETING = 3

    # The data source is experiencing an issue and might be unusable.
    ERROR = 4
  end
end

#name::String (readonly)

Returns Output only. Identifier. Name of the datasource to create. It must have the format"projects/{project}/locations/{location}/backupVaults/{backupvault}/dataSources/{datasource}". {datasource} cannot be changed after creation. It must be between 3-63 characters long and must be unique within the backup vault.

Returns:

  • (::String)

    Output only. Identifier. Name of the datasource to create. It must have the format"projects/{project}/locations/{location}/backupVaults/{backupvault}/dataSources/{datasource}". {datasource} cannot be changed after creation. It must be between 3-63 characters long and must be unique within the backup vault.



252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
# File 'proto_docs/google/cloud/backupdr/v1/backupvault.rb', line 252

class DataSource
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Holds the state of the data source resource.
  module State
    # State not set.
    STATE_UNSPECIFIED = 0

    # The data source is being created.
    CREATING = 1

    # The data source has been created and is fully usable.
    ACTIVE = 2

    # The data source is being deleted.
    DELETING = 3

    # The data source is experiencing an issue and might be unusable.
    ERROR = 4
  end
end

#state::Google::Cloud::BackupDR::V1::DataSource::State (readonly)

Returns Output only. The DataSource resource instance state.

Returns:



252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
# File 'proto_docs/google/cloud/backupdr/v1/backupvault.rb', line 252

class DataSource
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Holds the state of the data source resource.
  module State
    # State not set.
    STATE_UNSPECIFIED = 0

    # The data source is being created.
    CREATING = 1

    # The data source has been created and is fully usable.
    ACTIVE = 2

    # The data source is being deleted.
    DELETING = 3

    # The data source is experiencing an issue and might be unusable.
    ERROR = 4
  end
end

#total_stored_bytes::Integer

Returns The number of bytes (metadata and data) stored in this datasource.

Returns:

  • (::Integer)

    The number of bytes (metadata and data) stored in this datasource.



252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
# File 'proto_docs/google/cloud/backupdr/v1/backupvault.rb', line 252

class DataSource
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Holds the state of the data source resource.
  module State
    # State not set.
    STATE_UNSPECIFIED = 0

    # The data source is being created.
    CREATING = 1

    # The data source has been created and is fully usable.
    ACTIVE = 2

    # The data source is being deleted.
    DELETING = 3

    # The data source is experiencing an issue and might be unusable.
    ERROR = 4
  end
end

#update_time::Google::Protobuf::Timestamp (readonly)

Returns Output only. The time when the instance was updated.

Returns:



252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
# File 'proto_docs/google/cloud/backupdr/v1/backupvault.rb', line 252

class DataSource
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Holds the state of the data source resource.
  module State
    # State not set.
    STATE_UNSPECIFIED = 0

    # The data source is being created.
    CREATING = 1

    # The data source has been created and is fully usable.
    ACTIVE = 2

    # The data source is being deleted.
    DELETING = 3

    # The data source is experiencing an issue and might be unusable.
    ERROR = 4
  end
end