Class: Google::Cloud::BackupDR::V1::ListResourceBackupConfigsRequest
- Inherits:
-
Object
- Object
- Google::Cloud::BackupDR::V1::ListResourceBackupConfigsRequest
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/backupdr/v1/protection_summary.rb
Overview
Request for ListResourceBackupConfigs.
Instance Attribute Summary collapse
-
#filter ⇒ ::String
Optional.
-
#order_by ⇒ ::String
Optional.
-
#page_size ⇒ ::Integer
Optional.
-
#page_token ⇒ ::String
Optional.
-
#parent ⇒ ::String
Required.
Instance Attribute Details
#filter ⇒ ::String
Returns Optional. Filtering results.
45 46 47 48 |
# File 'proto_docs/google/cloud/backupdr/v1/protection_summary.rb', line 45 class ListResourceBackupConfigsRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#order_by ⇒ ::String
Returns Optional. Hint for how to order the results.
45 46 47 48 |
# File 'proto_docs/google/cloud/backupdr/v1/protection_summary.rb', line 45 class ListResourceBackupConfigsRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#page_size ⇒ ::Integer
Returns Optional. Requested page size. Server may return fewer items than requested. If unspecified, server will use 100 as default. Maximum value is 500 and values above 500 will be coerced to 500.
45 46 47 48 |
# File 'proto_docs/google/cloud/backupdr/v1/protection_summary.rb', line 45 class ListResourceBackupConfigsRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#page_token ⇒ ::String
Returns Optional. A token identifying a page of results the server should return.
45 46 47 48 |
# File 'proto_docs/google/cloud/backupdr/v1/protection_summary.rb', line 45 class ListResourceBackupConfigsRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#parent ⇒ ::String
Returns Required. The project and location for which to retrieve resource backup configs. Format: 'projects/{project_id}/locations/{location}'. In Google Cloud Backup and DR, locations map to Google Cloud regions, for example us-central1.
45 46 47 48 |
# File 'proto_docs/google/cloud/backupdr/v1/protection_summary.rb', line 45 class ListResourceBackupConfigsRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |