Class: Google::Cloud::BackupDR::V1::ListResourceBackupConfigsResponse
- Inherits:
-
Object
- Object
- Google::Cloud::BackupDR::V1::ListResourceBackupConfigsResponse
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/backupdr/v1/protection_summary.rb
Overview
Response for ListResourceBackupConfigs.
Instance Attribute Summary collapse
-
#next_page_token ⇒ ::String
A token identifying a page of results the server should return.
-
#resource_backup_configs ⇒ ::Array<::Google::Cloud::BackupDR::V1::ResourceBackupConfig>
The list of ResourceBackupConfigs for the specified scope.
Instance Attribute Details
#next_page_token ⇒ ::String
Returns A token identifying a page of results the server should return.
57 58 59 60 |
# File 'proto_docs/google/cloud/backupdr/v1/protection_summary.rb', line 57 class ListResourceBackupConfigsResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#resource_backup_configs ⇒ ::Array<::Google::Cloud::BackupDR::V1::ResourceBackupConfig>
Returns The list of ResourceBackupConfigs for the specified scope.
57 58 59 60 |
# File 'proto_docs/google/cloud/backupdr/v1/protection_summary.rb', line 57 class ListResourceBackupConfigsResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |